package com.bwie.formaiton.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Formation;
import com.bwie.common.domain.User;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.formaiton.mapper.FormationMapper;
import com.bwie.formaiton.service.FormationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@Service
public class FormationServiceImpl implements FormationService {

    @Autowired
    private FormationMapper formationMapper;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;
   @Override
    public Result<List<Formation>> list() {
        // 调用formationMapper的list方法，获取Formation列表
        List<Formation> list = formationMapper.list();
        // 返回成功结果，包含Formation列表
        return Result.success(list);
    }

   @Override
    public Result<Integer> insert(Formation formation) {
        // 获取token
        String token = request.getHeader(TokenConstants.TOKEN);
        // 获取用户key
        String userKey = JwtUtils.getUserKey(token);
        // 从redis中获取用户信息
        String s = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        // 将用户信息转换成User对象
        User user = JSON.parseObject(s, User.class);
        // 将用户信息设置到formation对象中
        formation.setUserId(user.getId());
        formation.setUserName(user.getUsername());
        formation.setUserPwd(user.getPassword());
        // 插入formation表
        Integer i = formationMapper.insert(formation);
        // 返回插入的条数
        return Result.success(i);
    }
}
