package com.bwie.health.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Health;
import com.bwie.common.domain.User;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.health.mapper.HealthMapper;
import com.bwie.health.service.HealthService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@Service
public class HealthServiceImpl implements HealthService{
    @Autowired
    private HealthMapper healthMapper;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;
    @Autowired
    private HttpServletRequest request;

    /*查看内容*/
   @Override
    public Result<PageInfo<Health>> list(Health health) {
        // 调用PageHelper的startPage方法，传入当前页码和每页条数
        PageHelper.startPage(health.getPageNum(),health.getPageSize());
        // 调用healthMapper的list方法，传入health参数
        List<Health> list = healthMapper.list(health);
        // 创建PageInfo对象，传入list
        PageInfo<Health> info = new PageInfo<>(list);
        // 返回Result.success方法，传入info
        return Result.success(info);
    }
    /*健康教育信息录入*/
   @Override
    public Result<Integer> addHealth(Health health) {
        //获取token
        String token1 = request.getHeader("token");
        //根据token获取用户key
        String userKey = JwtUtils.getUserKey(token1);
        //根据用户key获取token
        String token = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY+userKey);
        //根据token解析出用户信息
        User o = JSONObject.parseObject(token, User.class);
        //将用户信息设置到health中
        health.setUserId(o.getId());

        //调用healthMapper的addHealth方法添加health
        Integer i = healthMapper.addHealth(health);

        //根据返回结果返回对应信息
        return Result.success(i,i>0?"录入成功":"录入失败");
    }

    /*健康教育记录修改*/
    @Override
    public Result<Integer> updateHealth(Health health) {
        Integer i = healthMapper.updateHealth(health);
        return Result.success(i,i>0?"修改成功":"修改失败");
    }

    /*健康教育记录删除*/
    @Override
    public Result<Integer> deleteHealth(String healthId) {
        Integer i = healthMapper.deleteHealth(healthId);
        return Result.success(i,i>0?"删除成功":"删除失败");
    }
}
